[Libreoffice-commits] core.git: 16 commits - external/boost i18npool/source include/canvas include/connectivity include/filter include/osl include/sfx2 include/svx lotuswordpro/source registry/source sc/qa sc/source sw/source vcl/inc
Thomas Arnhold
thomas at arnhold.org
Sat Aug 16 20:17:46 PDT 2014
external/boost/UnpackedTarball_boost.mk | 6 -
i18npool/source/localedata/filewriter.cxx | 2
include/canvas/base/graphicdevicebase.hxx | 108 +++++++++++++-------------
include/connectivity/FValue.hxx | 4
include/filter/msfilter/mstoolbar.hxx | 2
include/osl/file.hxx | 4
include/sfx2/docfilt.hxx | 14 +--
include/sfx2/templateabstractview.hxx | 2
include/svx/fmtools.hxx | 100 ++++++++++++------------
lotuswordpro/source/filter/lwpborderstuff.cxx | 2
lotuswordpro/source/filter/lwpdlvlist.cxx | 2
lotuswordpro/source/filter/lwpdoc.hxx | 4
lotuswordpro/source/filter/lwpfrib.cxx | 2
lotuswordpro/source/filter/lwpmarker.cxx | 2
lotuswordpro/source/filter/lwpoverride.cxx | 2
lotuswordpro/source/filter/lwppara.cxx | 2
lotuswordpro/source/filter/lwpsection.cxx | 4
registry/source/keyimpl.cxx | 4
registry/source/keyimpl.hxx | 12 +-
sc/qa/unit/ucalc.cxx | 2
sc/source/ui/inc/viewdata.hxx | 4
sw/source/core/inc/frame.hxx | 28 +++---
sw/source/core/layout/findfrm.cxx | 8 -
sw/source/core/text/porlin.hxx | 24 ++---
vcl/inc/outdata.hxx | 4
25 files changed, 174 insertions(+), 174 deletions(-)
New commits:
commit fceb7534bfc9cece328c1f7c310ecdd0f707ba15
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 04:17:21 2014 +0200
fix unit test after size_t change
Change-Id: I511fd2c11fc1506c0cf7532347cca7933ed8ed5a
diff --git a/sc/qa/unit/ucalc.cxx b/sc/qa/unit/ucalc.cxx
index d9097bf..f06c2fc 100644
--- a/sc/qa/unit/ucalc.cxx
+++ b/sc/qa/unit/ucalc.cxx
@@ -3054,7 +3054,7 @@ void Test::testGraphicsOnSheetMove()
pPage = pDrawLayer->GetPage(1);
CPPUNIT_ASSERT_MESSAGE("No page instance for the 2nd sheet.", pPage);
- CPPUNIT_ASSERT_EQUAL_MESSAGE("2nd sheet shouldn't have any object.", pPage->GetObjCount(), static_cast<sal_uIntPtr>(0));
+ CPPUNIT_ASSERT_EQUAL_MESSAGE("2nd sheet shouldn't have any object.", pPage->GetObjCount(), static_cast<size_t>(0));
// Insert a new sheet at left-end, and make sure the object has moved to
// the 2nd page.
commit 1f1dfcdc91f55c87bbd80dbca09209c547907746
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 04:06:56 2014 +0200
boost: update patch states
Change-Id: I08d9692f42bd5bbce2d0c893b2eaf7eb65d4f2aa
diff --git a/external/boost/UnpackedTarball_boost.mk b/external/boost/UnpackedTarball_boost.mk
index 23fb367..237d97d 100644
--- a/external/boost/UnpackedTarball_boost.mk
+++ b/external/boost/UnpackedTarball_boost.mk
@@ -35,13 +35,13 @@ boost_patches += boost.date_time.Wshadow.warnings.patch
boost_patches += boost.date_time.Wunused-local-typedefs.warnings.patch
# fixed upstream
boost_patches += boost.math.Wdeprecated-register.patch.0
-# https://svn.boost.org/trac/boost/ticket/9884
+# fixed upstream
boost_patches += boost.math.Wunused-local-typedefs.warnings.patch
# https://svn.boost.org/trac/boost/ticket/9885
boost_patches += boost.multi_array.C4510.warnings.patch
# https://svn.boost.org/trac/boost/ticket/9886
boost_patches += boost.multi_array.Wshadow.warnings.patch.2
-# https://svn.boost.org/trac/boost/ticket/9887
+# fixed upstream
boost_patches += boost.multi_array.Wundef.warnings.patch
# https://svn.boost.org/trac/boost/ticket/9888
boost_patches += boost.multi_array.Wunused-local-typedefs.warnings.patch
@@ -76,7 +76,7 @@ boost_patches += boost.spirit.Wunused-parameter.warnings.patch
boost_patches += boost.date_time.Wshadow.warnings.patch.1
# fixed upstream
boost_patches += boost.unordered.Wshadow.warnings.patch
-# https://svn.boost.org/trac/boost/ticket/9902
+# fixed upstream
boost_patches += boost.tuple.Wunused-local-typedefs.warnings.patch
# https://svn.boost.org/trac/boost/ticket/9903
boost_patches += boost.utility.Wundef.warnings.patch
commit 2b4c54aa1363bf450e91172ad67db33de63c5963
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:57:20 2014 +0200
warning C4800: forcing value to bool 'true' or 'false'
Change-Id: I0bea774cd903f93721de6ffd8ed4ff9f5a15ef81
diff --git a/include/sfx2/templateabstractview.hxx b/include/sfx2/templateabstractview.hxx
index cd51d2b..00ecf03 100644
--- a/include/sfx2/templateabstractview.hxx
+++ b/include/sfx2/templateabstractview.hxx
@@ -112,7 +112,7 @@ public:
const OUString& getCurRegionName () const { return maCurRegionName;}
// Check if the root region is visible or not.
- bool isNonRootRegionVisible () const { return mnCurRegionId;}
+ bool isNonRootRegionVisible () const { return mnCurRegionId > 0;}
void setOpenRegionHdl(const Link &rLink);
commit f05d1812c069ad4471da21a8b6a0f9cc7717e37e
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:55:03 2014 +0200
warning C4800: forcing value to bool 'true' or 'false'
Change-Id: I116d5e14116e6853765bce552b6b8a71c835942e
diff --git a/lotuswordpro/source/filter/lwpborderstuff.cxx b/lotuswordpro/source/filter/lwpborderstuff.cxx
index e1d5e88..af80668 100644
--- a/lotuswordpro/source/filter/lwpborderstuff.cxx
+++ b/lotuswordpro/source/filter/lwpborderstuff.cxx
@@ -158,7 +158,7 @@ void LwpBorderStuff::Read(LwpObjectStream *pStrm)
bool LwpBorderStuff::HasSide(sal_uInt16 side)
{
- return m_nSides&side;
+ return (m_nSides & side) != 0;
}
sal_uInt16 LwpBorderStuff::GetSideType(sal_uInt16 side)
diff --git a/lotuswordpro/source/filter/lwpdlvlist.cxx b/lotuswordpro/source/filter/lwpdlvlist.cxx
index 1698e68..673e619 100644
--- a/lotuswordpro/source/filter/lwpdlvlist.cxx
+++ b/lotuswordpro/source/filter/lwpdlvlist.cxx
@@ -143,7 +143,7 @@ void LwpDLNFPVList::ReadPropertyList(LwpObjectStream* pObjStrm)
{
if( LwpFileHeader::m_nFileRevision >= 0x0000B)
{
- m_bHasProperties = pObjStrm->QuickReaduInt8();
+ m_bHasProperties = pObjStrm->QuickReaduInt8() != 0;
if (m_bHasProperties)
{
m_pPropList = new LwpPropList;
diff --git a/lotuswordpro/source/filter/lwpfrib.cxx b/lotuswordpro/source/filter/lwpfrib.cxx
index 32c6120..61d5324 100644
--- a/lotuswordpro/source/filter/lwpfrib.cxx
+++ b/lotuswordpro/source/filter/lwpfrib.cxx
@@ -132,7 +132,7 @@ LwpFrib* LwpFrib::CreateFrib(LwpPara* pPara, LwpObjectStream* pObjStrm, sal_uInt
break;
case FRIB_TAG_TEXT:
{
- newFrib = new LwpFribText (pPara, fribtag & FRIB_TAG_NOUNICODE);
+ newFrib = new LwpFribText (pPara, (fribtag & FRIB_TAG_NOUNICODE) != 0);
break;
}
case FRIB_TAG_TABLE:
diff --git a/lotuswordpro/source/filter/lwpmarker.cxx b/lotuswordpro/source/filter/lwpmarker.cxx
index c7f55d3..f94410f 100644
--- a/lotuswordpro/source/filter/lwpmarker.cxx
+++ b/lotuswordpro/source/filter/lwpmarker.cxx
@@ -300,7 +300,7 @@ bool LwpCHBlkMarker::IsHasFilled()
bool LwpCHBlkMarker::IsBubbleHelp()
{
- return (CHB_HELP & m_nFlag);
+ return (CHB_HELP & m_nFlag) != 0;
}
void LwpCHBlkMarker::EnumAllKeywords()
diff --git a/lotuswordpro/source/filter/lwpoverride.cxx b/lotuswordpro/source/filter/lwpoverride.cxx
index 814689a..1563f9a 100644
--- a/lotuswordpro/source/filter/lwpoverride.cxx
+++ b/lotuswordpro/source/filter/lwpoverride.cxx
@@ -170,7 +170,7 @@ void LwpTextAttributeOverride::Read(LwpObjectStream* pStrm)
bool LwpTextAttributeOverride::IsHighlight()
{
- return (m_nValues & TAO_HIGHLIGHT);
+ return (m_nValues & TAO_HIGHLIGHT) != 0;
}
/*class LwpKinsokuOptsOverride*/
diff --git a/lotuswordpro/source/filter/lwppara.cxx b/lotuswordpro/source/filter/lwppara.cxx
index 3fbf44e..c18319e 100644
--- a/lotuswordpro/source/filter/lwppara.cxx
+++ b/lotuswordpro/source/filter/lwppara.cxx
@@ -166,7 +166,7 @@ void LwpPara::Read()
if(LwpFileHeader::m_nFileRevision<0x0006)
Simple = false;
else if(LwpFileHeader::m_nFileRevision<0x000B)
- Simple = m_pObjStrm->QuickReaduInt8();
+ Simple = m_pObjStrm->QuickReaduInt8() != 0;
else
{
sal_uInt8 Flag = m_pObjStrm->QuickReaduInt8();
diff --git a/lotuswordpro/source/filter/lwpsection.cxx b/lotuswordpro/source/filter/lwpsection.cxx
index 4283856..ba9c512 100644
--- a/lotuswordpro/source/filter/lwpsection.cxx
+++ b/lotuswordpro/source/filter/lwpsection.cxx
@@ -148,13 +148,13 @@ void LwpIndexSection::Read()
bool LwpIndexSection::IsFormatRunin()
{
- return (m_nFlags & RUN_IN);
+ return (m_nFlags & RUN_IN) != 0;
}
bool LwpIndexSection::IsFormatSeparator()
{
- return (m_nFlags & SEPARATORS);
+ return (m_nFlags & SEPARATORS) != 0;
}
commit 159eb0839909991c3f8206f3b1862587f2919d0a
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:47:53 2014 +0200
warning C4800: 'sal_uInt32' : forcing value to bool 'true' or 'false'
Change-Id: Ib04d885fdbf3f46be08c857a28fcea210be1623a
diff --git a/lotuswordpro/source/filter/lwpdoc.hxx b/lotuswordpro/source/filter/lwpdoc.hxx
index 724fea7..a1dfee2 100644
--- a/lotuswordpro/source/filter/lwpdoc.hxx
+++ b/lotuswordpro/source/filter/lwpdoc.hxx
@@ -180,11 +180,11 @@ private:
inline bool LwpDocument::IsChildDoc()
{
- return (m_nPersistentFlags & DOC_CHILDDOC);
+ return (m_nPersistentFlags & DOC_CHILDDOC) != 0;
}
inline bool LwpDocument::HonorProtection()
{
- return m_nPersistentFlags & DOC_PROTECTED;
+ return (m_nPersistentFlags & DOC_PROTECTED) != 0;
}
inline LwpObjectID& LwpDocument::GetContentList()
{
commit 05acd6da8def7b57928fbbfa99e4a4416acf7aa5
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:38:27 2014 +0200
namespace css
Change-Id: Ie25cc7098cd513a77d78e04564eccacd946c355b
diff --git a/include/canvas/base/graphicdevicebase.hxx b/include/canvas/base/graphicdevicebase.hxx
index 3a77bfa..16f6ca1 100644
--- a/include/canvas/base/graphicdevicebase.hxx
+++ b/include/canvas/base/graphicdevicebase.hxx
@@ -57,11 +57,11 @@ namespace canvas
<pre>
Example:
- typedef ::cppu::WeakComponentImplHelper5< ::com::sun::star::rendering::XGraphicDevice,
- ::com::sun::star::rendering::XColorSpace,
- ::com::sun::star::rendering::XPropertySet,
- ::com::sun::star::lang::XServiceInfo,
- ::com::sun::star::lang::XServiceName > GraphicDeviceBase_Base;
+ typedef ::cppu::WeakComponentImplHelper5< css::rendering::XGraphicDevice,
+ css::rendering::XColorSpace,
+ css::rendering::XPropertySet,
+ css::lang::XServiceInfo,
+ css::lang::XServiceName > GraphicDeviceBase_Base;
typedef ::canvas::internal::GraphicDeviceBase< GraphicDeviceBase, DeviceHelper > ExampleDevice_Base;
class ExampleDevice : public ExampleDevice_Base
@@ -101,7 +101,7 @@ namespace canvas
template< class Base,
class DeviceHelper,
class Mutex=::osl::MutexGuard,
- class UnambiguousBase=::com::sun::star::uno::XInterface > class GraphicDeviceBase :
+ class UnambiguousBase=css::uno::XInterface > class GraphicDeviceBase :
public Base
{
public:
@@ -147,48 +147,48 @@ namespace canvas
}
// XGraphicDevice
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XBufferController > SAL_CALL getBufferController( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XBufferController > SAL_CALL getBufferController( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
- return ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XBufferController >();
+ return css::uno::Reference< css::rendering::XBufferController >();
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XColorSpace > SAL_CALL getDeviceColorSpace( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XColorSpace > SAL_CALL getDeviceColorSpace( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.getColorSpace();
}
- virtual ::com::sun::star::geometry::RealSize2D SAL_CALL getPhysicalResolution( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::geometry::RealSize2D SAL_CALL getPhysicalResolution( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.getPhysicalResolution();
}
- virtual ::com::sun::star::geometry::RealSize2D SAL_CALL getPhysicalSize( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::geometry::RealSize2D SAL_CALL getPhysicalSize( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.getPhysicalSize();
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XLinePolyPolygon2D > SAL_CALL createCompatibleLinePolyPolygon( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::geometry::RealPoint2D > >& points ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XLinePolyPolygon2D > SAL_CALL createCompatibleLinePolyPolygon( const css::uno::Sequence< css::uno::Sequence< css::geometry::RealPoint2D > >& points ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.createCompatibleLinePolyPolygon( this, points );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XBezierPolyPolygon2D > SAL_CALL createCompatibleBezierPolyPolygon( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::geometry::RealBezierSegment2D > >& points ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XBezierPolyPolygon2D > SAL_CALL createCompatibleBezierPolyPolygon( const css::uno::Sequence< css::uno::Sequence< css::geometry::RealBezierSegment2D > >& points ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.createCompatibleBezierPolyPolygon( this, points );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XBitmap > SAL_CALL createCompatibleBitmap( const ::com::sun::star::geometry::IntegerSize2D& size ) throw (::com::sun::star::lang::IllegalArgumentException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XBitmap > SAL_CALL createCompatibleBitmap( const css::geometry::IntegerSize2D& size ) throw (css::lang::IllegalArgumentException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
tools::verifyBitmapSize(size,
BOOST_CURRENT_FUNCTION,
@@ -199,8 +199,8 @@ namespace canvas
return maDeviceHelper.createCompatibleBitmap( this, size );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XVolatileBitmap > SAL_CALL createVolatileBitmap( const ::com::sun::star::geometry::IntegerSize2D& size ) throw (::com::sun::star::lang::IllegalArgumentException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XVolatileBitmap > SAL_CALL createVolatileBitmap( const css::geometry::IntegerSize2D& size ) throw (css::lang::IllegalArgumentException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
tools::verifyBitmapSize(size,
BOOST_CURRENT_FUNCTION,
@@ -211,8 +211,8 @@ namespace canvas
return maDeviceHelper.createVolatileBitmap( this, size );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XBitmap > SAL_CALL createCompatibleAlphaBitmap( const ::com::sun::star::geometry::IntegerSize2D& size ) throw (::com::sun::star::lang::IllegalArgumentException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XBitmap > SAL_CALL createCompatibleAlphaBitmap( const css::geometry::IntegerSize2D& size ) throw (css::lang::IllegalArgumentException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
tools::verifyBitmapSize(size,
BOOST_CURRENT_FUNCTION,
@@ -223,8 +223,8 @@ namespace canvas
return maDeviceHelper.createCompatibleAlphaBitmap( this, size );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XVolatileBitmap > SAL_CALL createVolatileAlphaBitmap( const ::com::sun::star::geometry::IntegerSize2D& size ) throw (::com::sun::star::lang::IllegalArgumentException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::rendering::XVolatileBitmap > SAL_CALL createVolatileAlphaBitmap( const css::geometry::IntegerSize2D& size ) throw (css::lang::IllegalArgumentException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
tools::verifyBitmapSize(size,
BOOST_CURRENT_FUNCTION,
@@ -235,19 +235,19 @@ namespace canvas
return maDeviceHelper.createVolatileAlphaBitmap( this, size );
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory > SAL_CALL getParametricPolyPolygonFactory( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::lang::XMultiServiceFactory > SAL_CALL getParametricPolyPolygonFactory( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
return this;
}
- virtual sal_Bool SAL_CALL hasFullScreenMode( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual sal_Bool SAL_CALL hasFullScreenMode( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maDeviceHelper.hasFullScreenMode();
}
- virtual sal_Bool SAL_CALL enterFullScreenMode( sal_Bool bEnter ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual sal_Bool SAL_CALL enterFullScreenMode( sal_Bool bEnter ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
@@ -255,23 +255,23 @@ namespace canvas
}
// XMultiServiceFactory
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > SAL_CALL createInstance( const OUString& aServiceSpecifier ) throw (::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::uno::XInterface > SAL_CALL createInstance( const OUString& aServiceSpecifier ) throw (css::uno::Exception, css::uno::RuntimeException) SAL_OVERRIDE
{
- return ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XParametricPolyPolygon2D >(
+ return css::uno::Reference< css::rendering::XParametricPolyPolygon2D >(
ParametricPolyPolygon::create(this,
aServiceSpecifier,
- ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >()));
+ css::uno::Sequence< css::uno::Any >()));
}
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > SAL_CALL createInstanceWithArguments( const OUString& aServiceSpecifier, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& Arguments ) throw (::com::sun::star::uno::Exception, ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::uno::XInterface > SAL_CALL createInstanceWithArguments( const OUString& aServiceSpecifier, const css::uno::Sequence< css::uno::Any >& Arguments ) throw (css::uno::Exception, css::uno::RuntimeException) SAL_OVERRIDE
{
- return ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XParametricPolyPolygon2D >(
+ return css::uno::Reference< css::rendering::XParametricPolyPolygon2D >(
ParametricPolyPolygon::create(this,
aServiceSpecifier,
Arguments));
}
- virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getAvailableServiceNames( ) throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< OUString > SAL_CALL getAvailableServiceNames( ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
return ParametricPolyPolygon::getAvailableServiceNames();
}
@@ -288,35 +288,35 @@ namespace canvas
// XPropertySet
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL getPropertySetInfo() throw (::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL getPropertySetInfo() throw (css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maPropHelper.getPropertySetInfo();
}
virtual void SAL_CALL setPropertyValue( const OUString& aPropertyName,
- const ::com::sun::star::uno::Any& aValue ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::beans::PropertyVetoException,
- ::com::sun::star::lang::IllegalArgumentException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ const css::uno::Any& aValue ) throw (css::beans::UnknownPropertyException,
+ css::beans::PropertyVetoException,
+ css::lang::IllegalArgumentException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
maPropHelper.setPropertyValue( aPropertyName, aValue );
}
- virtual ::com::sun::star::uno::Any SAL_CALL getPropertyValue( const OUString& aPropertyName ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL getPropertyValue( const OUString& aPropertyName ) throw (css::beans::UnknownPropertyException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
return maPropHelper.getPropertyValue( aPropertyName );
}
virtual void SAL_CALL addPropertyChangeListener( const OUString& aPropertyName,
- const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener >& xListener ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ const css::uno::Reference< css::beans::XPropertyChangeListener >& xListener ) throw (css::beans::UnknownPropertyException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
maPropHelper.addPropertyChangeListener( aPropertyName,
@@ -324,9 +324,9 @@ namespace canvas
}
virtual void SAL_CALL removePropertyChangeListener( const OUString& aPropertyName,
- const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener >& xListener ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ const css::uno::Reference< css::beans::XPropertyChangeListener >& xListener ) throw (css::beans::UnknownPropertyException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
maPropHelper.removePropertyChangeListener( aPropertyName,
@@ -334,9 +334,9 @@ namespace canvas
}
virtual void SAL_CALL addVetoableChangeListener( const OUString& aPropertyName,
- const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener >& xListener ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ const css::uno::Reference< css::beans::XVetoableChangeListener >& xListener ) throw (css::beans::UnknownPropertyException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
maPropHelper.addVetoableChangeListener( aPropertyName,
@@ -344,9 +344,9 @@ namespace canvas
}
virtual void SAL_CALL removeVetoableChangeListener( const OUString& aPropertyName,
- const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XVetoableChangeListener >& xListener ) throw (::com::sun::star::beans::UnknownPropertyException,
- ::com::sun::star::lang::WrappedTargetException,
- ::com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ const css::uno::Reference< css::beans::XVetoableChangeListener >& xListener ) throw (css::beans::UnknownPropertyException,
+ css::lang::WrappedTargetException,
+ css::uno::RuntimeException) SAL_OVERRIDE
{
MutexType aGuard( BaseType::m_aMutex );
maPropHelper.removeVetoableChangeListener( aPropertyName,
@@ -356,12 +356,12 @@ namespace canvas
protected:
~GraphicDeviceBase() {} // we're a ref-counted UNO class. _We_ destroy ourselves.
- ::com::sun::star::uno::Any getDumpScreenContent() const
+ css::uno::Any getDumpScreenContent() const
{
- return ::com::sun::star::uno::makeAny( mbDumpScreenContent );
+ return css::uno::makeAny( mbDumpScreenContent );
}
- void setDumpScreenContent( const ::com::sun::star::uno::Any& rAny )
+ void setDumpScreenContent( const css::uno::Any& rAny )
{
// TODO(Q1): this was mbDumpScreenContent =
// rAny.get<bool>(), only that gcc3.3 wouldn't eat it
commit 439c90916c15ee9647ef408a33eacf9150aed216
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:37:20 2014 +0200
warning C4800: 'int' : forcing value to bool 'true' or 'false'
Change-Id: I011954c2e12abb8a7551638567474e2123d3221e
diff --git a/include/filter/msfilter/mstoolbar.hxx b/include/filter/msfilter/mstoolbar.hxx
index 58af3c4..8dbea1b 100644
--- a/include/filter/msfilter/mstoolbar.hxx
+++ b/include/filter/msfilter/mstoolbar.hxx
@@ -275,7 +275,7 @@ public:
sal_uInt8 getTct() const { return tct; }
sal_uInt16 getTcID() const { return tcid; }
bool isVisible() { return !( bFlagsTCR & 0x1 ); }
- bool isBeginGroup() { return ( bFlagsTCR & 0x2 ); }
+ bool isBeginGroup() { return ( bFlagsTCR & 0x2 ) != 0; }
bool Read(SvStream &rS) SAL_OVERRIDE;
#if OSL_DEBUG_LEVEL > 1
virtual void Print( FILE* ) SAL_OVERRIDE;
commit 6d51e258b9b9017a01e266897fca86b3d1159e33
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:35:41 2014 +0200
warning C4800: 'int' : forcing value to bool 'true' or 'false'
Change-Id: I9f77b85eb9ccaa4defa3dea571b375c0e480caa2
diff --git a/vcl/inc/outdata.hxx b/vcl/inc/outdata.hxx
index 8b5243d..f48f0f9 100644
--- a/vcl/inc/outdata.hxx
+++ b/vcl/inc/outdata.hxx
@@ -28,9 +28,9 @@ inline SalColor ImplColorToSal( Color aColor )
return MAKE_SALCOLOR( aColor.GetRed(), aColor.GetGreen(), aColor.GetBlue() );
}
-inline int ImplIsColorTransparent( Color aColor )
+inline bool ImplIsColorTransparent( Color aColor )
{
- return aColor.GetTransparency();
+ return aColor.GetTransparency() != 0;
}
#endif // INCLUDED_VCL_INC_OUTDATA_HXX
commit ebac76936d995deff24ea7e0ab625c7366c632ac
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:30:34 2014 +0200
namespace css
Change-Id: I58017a0769a1e06d9e870f692c2d9fcfd347fbd7
diff --git a/sw/source/core/inc/frame.hxx b/sw/source/core/inc/frame.hxx
index 0433e7e..825b452 100644
--- a/sw/source/core/inc/frame.hxx
+++ b/sw/source/core/inc/frame.hxx
@@ -1140,7 +1140,7 @@ inline const SwFrm *SwFrm::FindPrev() const
inline bool SwFrm::IsLayoutFrm() const
{
- return GetType() & FRM_LAYOUT;
+ return (GetType() & FRM_LAYOUT) != 0;
}
inline bool SwFrm::IsRootFrm() const
{
@@ -1156,7 +1156,7 @@ inline bool SwFrm::IsColumnFrm() const
}
inline bool SwFrm::IsFtnBossFrm() const
{
- return GetType() & FRM_FTNBOSS;
+ return (GetType() & FRM_FTNBOSS) != 0;
}
inline bool SwFrm::IsHeaderFrm() const
{
@@ -1200,7 +1200,7 @@ inline bool SwFrm::IsCellFrm() const
}
inline bool SwFrm::IsCntntFrm() const
{
- return GetType() & FRM_CNTNT;
+ return (GetType() & FRM_CNTNT) != 0;
}
inline bool SwFrm::IsTxtFrm() const
{
@@ -1212,15 +1212,15 @@ inline bool SwFrm::IsNoTxtFrm() const
}
inline bool SwFrm::IsFlowFrm() const
{
- return GetType() & 0xCA00; //TabFrm, CntntFrm, SectionFrm
+ return (GetType() & 0xCA00) != 0; //TabFrm, CntntFrm, SectionFrm
}
inline bool SwFrm::IsRetoucheFrm() const
{
- return GetType() & 0xCA40; //TabFrm, CntntFrm, SectionFrm, Ftnfrm
+ return (GetType() & 0xCA40) != 0; //TabFrm, CntntFrm, SectionFrm, Ftnfrm
}
inline bool SwFrm::IsAccessibleFrm() const
{
- return GetType() & FRM_ACCESSIBLE;
+ return (GetType() & FRM_ACCESSIBLE) != 0;
}
#endif
commit eb8d716fb57ee1cf1c1b6b0057f296bf2f79e5f9
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:16:40 2014 +0200
warning C4800: 'int' : forcing value to bool 'true' or 'false'
Change-Id: Iae7dd3944d1d01020c8a3ab1ac4bb2e94e01541e
diff --git a/sw/source/core/text/porlin.hxx b/sw/source/core/text/porlin.hxx
index 567b408..8e0eb6c 100644
--- a/sw/source/core/text/porlin.hxx
+++ b/sw/source/core/text/porlin.hxx
@@ -108,18 +108,18 @@ public:
inline sal_uInt16 GetWhichPor( ) const { return nWhichPor; }
// Group queries
- inline bool InTxtGrp() const { return nWhichPor & PORGRP_TXT; }
- inline bool InGlueGrp() const { return nWhichPor & PORGRP_GLUE; }
- inline bool InTabGrp() const { return nWhichPor & PORGRP_TAB; }
- inline bool InHyphGrp() const { return nWhichPor & PORGRP_HYPH; }
- inline bool InNumberGrp() const { return nWhichPor & PORGRP_NUMBER; }
- inline bool InFixGrp() const { return nWhichPor & PORGRP_FIX; }
- inline bool InFldGrp() const { return nWhichPor & PORGRP_FLD; }
- inline bool InToxRefGrp() const { return nWhichPor & PORGRP_TOXREF; }
- inline bool InToxRefOrFldGrp() const { return nWhichPor & ( PORGRP_FLD | PORGRP_TOXREF ); }
- inline bool InExpGrp() const { return nWhichPor & PORGRP_EXP; }
- inline bool InTabnLftGrp() const { return nWhichPor & PORGRP_TABNOTLFT; }
- inline bool InFixMargGrp() const { return nWhichPor & PORGRP_FIXMARG; }
+ inline bool InTxtGrp() const { return (nWhichPor & PORGRP_TXT) != 0; }
+ inline bool InGlueGrp() const { return (nWhichPor & PORGRP_GLUE) != 0; }
+ inline bool InTabGrp() const { return (nWhichPor & PORGRP_TAB) != 0; }
+ inline bool InHyphGrp() const { return (nWhichPor & PORGRP_HYPH) != 0; }
+ inline bool InNumberGrp() const { return (nWhichPor & PORGRP_NUMBER) != 0; }
+ inline bool InFixGrp() const { return (nWhichPor & PORGRP_FIX) != 0; }
+ inline bool InFldGrp() const { return (nWhichPor & PORGRP_FLD) != 0; }
+ inline bool InToxRefGrp() const { return (nWhichPor & PORGRP_TOXREF) != 0; }
+ inline bool InToxRefOrFldGrp() const { return (nWhichPor & ( PORGRP_FLD | PORGRP_TOXREF )) != 0; }
+ inline bool InExpGrp() const { return (nWhichPor & PORGRP_EXP) != 0; }
+ inline bool InTabnLftGrp() const { return (nWhichPor & PORGRP_TABNOTLFT) != 0; }
+ inline bool InFixMargGrp() const { return (nWhichPor & PORGRP_FIXMARG) != 0; }
inline bool InSpaceGrp() const { return InTxtGrp() || IsMultiPortion(); }
// Individual queries
inline bool IsGrfNumPortion() const { return nWhichPor == POR_GRFNUM; }
commit fe3b29126ee5aa054424dc8c3dcc2e4c64398984
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:13:27 2014 +0200
warning C4800: 'unsigned long' : forcing value to bool 'true' or 'false'
Change-Id: Iea71e791a760b38448a89294ab4136f815b8932c
diff --git a/include/sfx2/docfilt.hxx b/include/sfx2/docfilt.hxx
index f4fb63e..34d7130 100644
--- a/include/sfx2/docfilt.hxx
+++ b/include/sfx2/docfilt.hxx
@@ -77,13 +77,13 @@ public:
const OUString& rServiceName );
~SfxFilter();
- bool IsAllowedAsTemplate() const { return nFormatType & SFX_FILTER_TEMPLATE; }
- bool IsOwnFormat() const { return nFormatType & SFX_FILTER_OWN; }
- bool IsOwnTemplateFormat() const { return nFormatType & SFX_FILTER_TEMPLATEPATH; }
- bool IsAlienFormat() const { return nFormatType & SFX_FILTER_ALIEN; }
- bool CanImport() const { return nFormatType & SFX_FILTER_IMPORT; }
- bool CanExport() const { return nFormatType & SFX_FILTER_EXPORT; }
- bool IsInternal() const { return nFormatType & SFX_FILTER_INTERNAL; }
+ bool IsAllowedAsTemplate() const { return (nFormatType & SFX_FILTER_TEMPLATE) != 0; }
+ bool IsOwnFormat() const { return (nFormatType & SFX_FILTER_OWN) != 0; }
+ bool IsOwnTemplateFormat() const { return (nFormatType & SFX_FILTER_TEMPLATEPATH) != 0; }
+ bool IsAlienFormat() const { return (nFormatType & SFX_FILTER_ALIEN) != 0; }
+ bool CanImport() const { return (nFormatType & SFX_FILTER_IMPORT) != 0; }
+ bool CanExport() const { return (nFormatType & SFX_FILTER_EXPORT) != 0; }
+ bool IsInternal() const { return (nFormatType & SFX_FILTER_INTERNAL) != 0; }
SfxFilterFlags GetFilterFlags() const { return nFormatType; }
const OUString& GetFilterName() const { return maFilterName; }
const OUString& GetMimeType() const { return aMimeType; }
commit 6c54831d071c8386fddd3e6f5e131c71a06d0a1e
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:12:21 2014 +0200
warning C4800: 'unsigned long' : forcing value to bool 'true' or 'false'
Change-Id: I7546fb8fd0a5b83818c8496d44ec180ec48e72eb
diff --git a/include/osl/file.hxx b/include/osl/file.hxx
index e946559..6307854 100644
--- a/include/osl/file.hxx
+++ b/include/osl/file.hxx
@@ -621,7 +621,7 @@ public:
*/
bool isCaseSensitiveFileSystem() const
{
- return (_aInfo.uAttributes & osl_Volume_Attribute_Case_Sensitive);
+ return (_aInfo.uAttributes & osl_Volume_Attribute_Case_Sensitive) != 0;
}
/** Return whether the file system preserves the case of
@@ -633,7 +633,7 @@ public:
*/
bool isCasePreservingFileSystem() const
{
- return (_aInfo.uAttributes & osl_Volume_Attribute_Case_Is_Preserved);
+ return (_aInfo.uAttributes & osl_Volume_Attribute_Case_Is_Preserved) != 0;
}
friend class Directory;
commit 4f1dabfd44c105d533689c181189868ce1cce79e
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:06:31 2014 +0200
warning C4800: 'int' : forcing value to bool 'true' or 'false'
Change-Id: Ic438fe098f80e96dd4679dda6e5de93a1ba9dc6a
diff --git a/sc/source/ui/inc/viewdata.hxx b/sc/source/ui/inc/viewdata.hxx
index bcbca56..bb3e263 100644
--- a/sc/source/ui/inc/viewdata.hxx
+++ b/sc/source/ui/inc/viewdata.hxx
@@ -285,8 +285,8 @@ public:
SCCOL GetFixPosX() const { return pThisTab->nFixPosX; }
SCROW GetFixPosY() const { return pThisTab->nFixPosY; }
bool IsPagebreakMode() const { return bPagebreak; }
- bool IsPasteMode() const { return nPasteFlags & SC_PASTE_MODE; }
- bool ShowPasteSource() const { return nPasteFlags & SC_PASTE_BORDER; }
+ bool IsPasteMode() const { return (nPasteFlags & SC_PASTE_MODE) != 0; }
+ bool ShowPasteSource() const { return (nPasteFlags & SC_PASTE_BORDER) != 0; }
void SetPosX( ScHSplitPos eWhich, SCCOL nNewPosX );
void SetPosY( ScVSplitPos eWhich, SCROW nNewPosY );
commit 0842a2707cfca15c0af5eee6ed9d76547a01a7f9
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 00:50:33 2014 +0200
use bool directly
Change-Id: I314e290b453c55e345559d8abef9b00622493ed3
diff --git a/i18npool/source/localedata/filewriter.cxx b/i18npool/source/localedata/filewriter.cxx
index 19b2558..9c30144 100644
--- a/i18npool/source/localedata/filewriter.cxx
+++ b/i18npool/source/localedata/filewriter.cxx
@@ -133,7 +133,7 @@ void OFileWriter::writeIntParameter(const sal_Char* pAsciiStr, const sal_Int16 c
bool OFileWriter::writeDefaultParameter(const sal_Char* pAsciiStr, const OUString& str, sal_Int16 count) const
{
- bool bBool = (str == "true" ? 1 : 0);
+ bool bBool = str == "true";
fprintf(m_f,"static const sal_Unicode default%s%d[] = {%d};\n", pAsciiStr, count, bBool);
return bBool;
}
diff --git a/include/connectivity/FValue.hxx b/include/connectivity/FValue.hxx
index 787785d..db1b289 100644
--- a/include/connectivity/FValue.hxx
+++ b/include/connectivity/FValue.hxx
@@ -372,10 +372,10 @@ namespace connectivity
}
bool isBound() const { return m_bBound; }
- void setBound(bool _bBound) { m_bBound = _bBound ? 1 : 0; }
+ void setBound(bool _bBound) { m_bBound = _bBound; }
bool isModified() const { return m_bModified; }
- void setModified(bool _bMod=true) { m_bModified = _bMod ? 1 : 0; }
+ void setModified(bool _bMod=true) { m_bModified = _bMod; }
bool isSigned() const { return m_bSigned; }
void setSigned(bool _bSig=true);
diff --git a/sw/source/core/inc/frame.hxx b/sw/source/core/inc/frame.hxx
index 8e6bd09..0433e7e 100644
--- a/sw/source/core/inc/frame.hxx
+++ b/sw/source/core/inc/frame.hxx
@@ -549,21 +549,21 @@ public:
bool IsInBalancedSection() const;
inline bool IsReverse() const { return mbReverse; }
- inline void SetReverse( bool bNew ){ mbReverse = bNew ? 1 : 0; }
+ inline void SetReverse( bool bNew ){ mbReverse; }
inline bool IsVertical() const;
inline bool IsVertLR() const;
inline bool GetVerticalFlag() const { return mbVertical; }
- inline void SetVertical( bool bNew ){ mbVertical = bNew ? 1 : 0; }
+ inline void SetVertical( bool bNew ){ mbVertical; }
- inline void SetbVertLR( bool bNew ) { mbVertLR = bNew ? 1 : 0; }
- inline void SetDerivedVert( bool bNew ){ mbDerivedVert = bNew ? 1 : 0; }
- inline void SetInvalidVert( bool bNew) { mbInvalidVert = bNew ? 1 : 0; }
+ inline void SetbVertLR( bool bNew ) { mbVertLR = bNew; }
+ inline void SetDerivedVert( bool bNew ){ mbDerivedVert = bNew; }
+ inline void SetInvalidVert( bool bNew) { mbInvalidVert = bNew; }
inline bool IsRightToLeft() const;
inline bool GetRightToLeftFlag() const { return mbRightToLeft; }
- inline void SetRightToLeft( bool bNew ){ mbRightToLeft = bNew ? 1 : 0; }
- inline void SetDerivedR2L( bool bNew ) { mbDerivedR2L = bNew ? 1 : 0; }
- inline void SetInvalidR2L( bool bNew ) { mbInvalidR2L = bNew ? 1 : 0; }
+ inline void SetRightToLeft( bool bNew ){ mbRightToLeft = bNew; }
+ inline void SetDerivedR2L( bool bNew ) { mbDerivedR2L = bNew; }
+ inline void SetInvalidR2L( bool bNew ) { mbInvalidR2L = bNew; }
void CheckDirChange();
// returns upper left frame position for LTR and
diff --git a/sw/source/core/layout/findfrm.cxx b/sw/source/core/layout/findfrm.cxx
index f712fd0..b6c9b00 100644
--- a/sw/source/core/layout/findfrm.cxx
+++ b/sw/source/core/layout/findfrm.cxx
@@ -1310,10 +1310,10 @@ void SwFrm::SetDirFlags( bool bVert )
if( pAsk )
{
- mbVertical = pAsk->IsVertical() ? 1 : 0;
- mbReverse = pAsk->IsReverse() ? 1 : 0;
+ mbVertical = pAsk->IsVertical();
+ mbReverse = pAsk->IsReverse();
- mbVertLR = pAsk->IsVertLR() ? 1 : 0;
+ mbVertLR = pAsk->IsVertLR();
if ( !pAsk->mbInvalidVert )
mbInvalidVert = false;
@@ -1335,7 +1335,7 @@ void SwFrm::SetDirFlags( bool bVert )
OSL_ENSURE( pAsk != this, "Oops! Stack overflow is about to happen" );
if( pAsk )
- mbRightToLeft = pAsk->IsRightToLeft() ? 1 : 0;
+ mbRightToLeft = pAsk->IsRightToLeft();
if( !pAsk || pAsk->mbInvalidR2L )
bInv = mbInvalidR2L;
}
commit e7641433c0079a35652893ab15ae6997e3e3a933
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 00:43:47 2014 +0200
convert int to bool
Change-Id: I4fb95c90dc1f188f8088ba1e4b7bfd0ebc59eb60
diff --git a/registry/source/keyimpl.cxx b/registry/source/keyimpl.cxx
index 52c2642..40f7983 100644
--- a/registry/source/keyimpl.cxx
+++ b/registry/source/keyimpl.cxx
@@ -36,8 +36,8 @@ namespace { static char const VALUE_PREFIX[] = "$VL_"; }
ORegKey::ORegKey(const OUString& keyName, ORegistry* pReg)
: m_refCount(1)
, m_name(keyName)
- , m_bDeleted(0)
- , m_bModified(0)
+ , m_bDeleted(false)
+ , m_bModified(false)
, m_pRegistry(pReg)
{
}
diff --git a/registry/source/keyimpl.hxx b/registry/source/keyimpl.hxx
index 189602f..c0b868f 100644
--- a/registry/source/keyimpl.hxx
+++ b/registry/source/keyimpl.hxx
@@ -97,16 +97,16 @@ public:
OUString& resolvedName);
bool isDeleted() const
- { return m_bDeleted != 0; }
+ { return m_bDeleted; }
void setDeleted (bool bKeyDeleted)
- { m_bDeleted = bKeyDeleted ? 1 : 0; }
+ { m_bDeleted = bKeyDeleted; }
bool isModified() const
- { return m_bModified != 0; }
+ { return m_bModified; }
void setModified (bool bModified = true)
- { m_bModified = bModified ? 1 : 0; }
+ { m_bModified = bModified; }
bool isReadOnly() const
{ return m_pRegistry->isReadOnly(); }
@@ -132,8 +132,8 @@ public:
private:
sal_uInt32 m_refCount;
OUString m_name;
- int m_bDeleted:1;
- int m_bModified:1;
+ bool m_bDeleted:1;
+ bool m_bModified:1;
ORegistry* m_pRegistry;
};
More information about the Libreoffice-commits
mailing list
diff --git a/include/svx/fmtools.hxx b/include/svx/fmtools.hxx
index b48c3f7..946599e 100644
--- a/include/svx/fmtools.hxx
+++ b/include/svx/fmtools.hxx
@@ -76,36 +76,36 @@ class Window;
// common types
// displaying a database exception for the user
-// display info about a simple ::com::sun::star::sdbc::SQLException
-void displayException(const ::com::sun::star::sdbc::SQLException&, Window* _pParent = NULL);
-void displayException(const ::com::sun::star::sdbc::SQLWarning&, Window* _pParent = NULL);
-SVX_DLLPUBLIC void displayException(const ::com::sun::star::sdb::SQLContext&, Window* _pParent = NULL);
-void displayException(const ::com::sun::star::sdb::SQLErrorEvent&, Window* _pParent = NULL);
-void displayException(const ::com::sun::star::uno::Any&, Window* _pParent = NULL);
+// display info about a simple css::sdbc::SQLException
+void displayException(const css::sdbc::SQLException&, Window* _pParent = NULL);
+void displayException(const css::sdbc::SQLWarning&, Window* _pParent = NULL);
+SVX_DLLPUBLIC void displayException(const css::sdb::SQLContext&, Window* _pParent = NULL);
+void displayException(const css::sdb::SQLErrorEvent&, Window* _pParent = NULL);
+void displayException(const css::uno::Any&, Window* _pParent = NULL);
-sal_Int32 getElementPos(const ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess>& xCont, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& xElement);
+sal_Int32 getElementPos(const css::uno::Reference< css::container::XIndexAccess>& xCont, const css::uno::Reference< css::uno::XInterface>& xElement);
-SVX_DLLPUBLIC OUString getLabelName(const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet>& xControlModel);
+SVX_DLLPUBLIC OUString getLabelName(const css::uno::Reference< css::beans::XPropertySet>& xControlModel);
-// = class CursorWrapper - a helper class which works in common with a ::com::sun::star::uno::Reference<XDatabaseUpdateCursor>,
+// = class CursorWrapper - a helper class which works in common with a css::uno::Reference<XDatabaseUpdateCursor>,
// XDatabaseBookmarkCursor and XDatabaseDirectCursor each
class CursorWrapper
{
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface> m_xGeneric;
- ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet> m_xMoveOperations;
- ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XRowLocate> m_xBookmarkOperations;
- ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XColumnsSupplier> m_xColumnsSupplier;
- ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet> m_xPropertyAccess;
+ css::uno::Reference< css::uno::XInterface> m_xGeneric;
+ css::uno::Reference< css::sdbc::XResultSet> m_xMoveOperations;
+ css::uno::Reference< css::sdbcx::XRowLocate> m_xBookmarkOperations;
+ css::uno::Reference< css::sdbcx::XColumnsSupplier> m_xColumnsSupplier;
+ css::uno::Reference< css::beans::XPropertySet> m_xPropertyAccess;
public:
// Construction/Destruction
CursorWrapper() { }
- CursorWrapper(const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet>& _rxCursor, bool bUseCloned = false);
- SVX_DLLPUBLIC CursorWrapper(const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet>& _rxCursor, bool bUseCloned = false);
+ CursorWrapper(const css::uno::Reference< css::sdbc::XRowSet>& _rxCursor, bool bUseCloned = false);
+ SVX_DLLPUBLIC CursorWrapper(const css::uno::Reference< css::sdbc::XResultSet>& _rxCursor, bool bUseCloned = false);
// if bUseCloned == sal_True, the cursor is first doubled over the XCloneable interface (which it must implement)
// and then used
@@ -118,34 +118,34 @@ public:
bool Is() const { return m_xMoveOperations.is(); }
CursorWrapper* operator ->() { return this; }
- operator const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& () const{ return m_xGeneric; }
+ operator const css::uno::Reference< css::uno::XInterface>& () const{ return m_xGeneric; }
// 'Conversions'
- const CursorWrapper& operator=(const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRowSet>& xCursor);
- operator const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet>& () const { return m_xMoveOperations; }
- operator const ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XRowLocate>& () const { return m_xBookmarkOperations; }
- operator const ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XColumnsSupplier>& () const { return m_xColumnsSupplier; }
+ const CursorWrapper& operator=(const css::uno::Reference< css::sdbc::XRowSet>& xCursor);
+ operator const css::uno::Reference< css::sdbc::XResultSet>& () const { return m_xMoveOperations; }
+ operator const css::uno::Reference< css::sdbcx::XRowLocate>& () const { return m_xBookmarkOperations; }
+ operator const css::uno::Reference< css::sdbcx::XColumnsSupplier>& () const { return m_xColumnsSupplier; }
- const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >& getPropertySet() const { return m_xPropertyAccess; }
- const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet >& getResultSet() const { return m_xMoveOperations; }
- const ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XRowLocate >& getRowLocate() const { return m_xBookmarkOperations; }
- const ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XColumnsSupplier >& getColumnsSupplier() const { return m_xColumnsSupplier; }
+ const css::uno::Reference< css::beans::XPropertySet >& getPropertySet() const { return m_xPropertyAccess; }
+ const css::uno::Reference< css::sdbc::XResultSet >& getResultSet() const { return m_xMoveOperations; }
+ const css::uno::Reference< css::sdbcx::XRowLocate >& getRowLocate() const { return m_xBookmarkOperations; }
+ const css::uno::Reference< css::sdbcx::XColumnsSupplier >& getColumnsSupplier() const { return m_xColumnsSupplier; }
// the usual queryInterface
- ::com::sun::star::uno::Any SAL_CALL queryInterface( const ::com::sun::star::uno::Type& type) throw ( ::com::sun::star::uno::RuntimeException )
+ css::uno::Any SAL_CALL queryInterface( const css::uno::Type& type) throw ( css::uno::RuntimeException )
{ return m_xMoveOperations->queryInterface(type); }
- // ::com::sun::star::uno::Reference< ::com::sun::star::sdbcx::XRowLocate>
- ::com::sun::star::uno::Any getBookmark(void)
- throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException )
+ // css::uno::Reference< css::sdbcx::XRowLocate>
+ css::uno::Any getBookmark(void)
+ throw( css::sdbc::SQLException, css::uno::RuntimeException )
{ return m_xBookmarkOperations->getBookmark(); }
- bool moveToBookmark(const ::com::sun::star::uno::Any& bookmark) throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException ) { return m_xBookmarkOperations->moveToBookmark(bookmark); }
- bool moveRelativeToBookmark(const ::com::sun::star::uno::Any& bookmark, sal_Int32 rows) throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException ) { return m_xBookmarkOperations->moveRelativeToBookmark(bookmark, rows); }
- sal_Int32 compareBookmarks(const ::com::sun::star::uno::Any& lhs, const ::com::sun::star::uno::Any& rhs) const throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException ) { return m_xBookmarkOperations->compareBookmarks(lhs, rhs); }
- sal_Int32 hasOrderedBookmarks(void) const throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException ) { return m_xBookmarkOperations->hasOrderedBookmarks(); }
- sal_Int32 hashBookmark(const ::com::sun::star::uno::Any& bookmark) const throw( ::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException ) { return m_xBookmarkOperations->hashBookmark(bookmark); }
+ bool moveToBookmark(const css::uno::Any& bookmark) throw( css::sdbc::SQLException, css::uno::RuntimeException ) { return m_xBookmarkOperations->moveToBookmark(bookmark); }
+ bool moveRelativeToBookmark(const css::uno::Any& bookmark, sal_Int32 rows) throw( css::sdbc::SQLException, css::uno::RuntimeException ) { return m_xBookmarkOperations->moveRelativeToBookmark(bookmark, rows); }
+ sal_Int32 compareBookmarks(const css::uno::Any& lhs, const css::uno::Any& rhs) const throw( css::sdbc::SQLException, css::uno::RuntimeException ) { return m_xBookmarkOperations->compareBookmarks(lhs, rhs); }
+ sal_Int32 hasOrderedBookmarks(void) const throw( css::sdbc::SQLException, css::uno::RuntimeException ) { return m_xBookmarkOperations->hasOrderedBookmarks(); }
+ sal_Int32 hashBookmark(const css::uno::Any& bookmark) const throw( css::sdbc::SQLException, css::uno::RuntimeException ) { return m_xBookmarkOperations->hashBookmark(bookmark); }
- // ::com::sun::star::sdbc::XResultSet
+ // css::sdbc::XResultSet
bool isBeforeFirst() const { return m_xMoveOperations->isBeforeFirst(); }
bool isAfterLast() const { return m_xMoveOperations->isAfterLast(); }
bool isFirst() const { return m_xMoveOperations->isFirst(); }
@@ -162,11 +162,11 @@ public:
bool rowUpdated() { return m_xMoveOperations->rowUpdated(); }
bool rowInserted() { return m_xMoveOperations->rowInserted(); }
bool rowDeleted() { return m_xMoveOperations->rowDeleted(); }
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface> getStatement() { return m_xMoveOperations->getStatement(); }
- // ::com::sun::star::sdbcx::XColumnsSupplier
- ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess> getColumns() const throw( ::com::sun::star::uno::RuntimeException ) { return m_xColumnsSupplier->getColumns(); }
+ css::uno::Reference< css::uno::XInterface> getStatement() { return m_xMoveOperations->getStatement(); }
+ // css::sdbcx::XColumnsSupplier
+ css::uno::Reference< css::container::XNameAccess> getColumns() const throw( css::uno::RuntimeException ) { return m_xColumnsSupplier->getColumns(); }
private:
- void ImplConstruct(const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet>& _rxCursor, bool bUseCloned);
+ void ImplConstruct(const css::uno::Reference< css::sdbc::XResultSet>& _rxCursor, bool bUseCloned);
};
@@ -182,7 +182,7 @@ public:
FmXDisposeListener(::osl::Mutex& _rMutex) : m_pAdapter(NULL), m_rMutex(_rMutex) { }
virtual ~FmXDisposeListener();
- virtual void disposing(const ::com::sun::star::lang::EventObject& _rEvent, sal_Int16 _nId) throw( ::com::sun::star::uno::RuntimeException ) = 0;
+ virtual void disposing(const css::lang::EventObject& _rEvent, sal_Int16 _nId) throw( css::uno::RuntimeException ) = 0;
protected:
void setAdapter(FmXDisposeMultiplexer* pAdapter);
@@ -190,34 +190,34 @@ protected:
-class FmXDisposeMultiplexer :public ::cppu::WeakImplHelper1< ::com::sun::star::lang::XEventListener>
+class FmXDisposeMultiplexer :public ::cppu::WeakImplHelper1< css::lang::XEventListener>
{
- ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent> m_xObject;
+ css::uno::Reference< css::lang::XComponent> m_xObject;
FmXDisposeListener* m_pListener;
sal_Int16 m_nId;
virtual ~FmXDisposeMultiplexer();
public:
- FmXDisposeMultiplexer(FmXDisposeListener* _pListener, const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent>& _rxObject, sal_Int16 _nId = -1);
+ FmXDisposeMultiplexer(FmXDisposeListener* _pListener, const css::uno::Reference< css::lang::XComponent>& _rxObject, sal_Int16 _nId = -1);
-// ::com::sun::star::lang::XEventListener
- virtual void SAL_CALL disposing( const ::com::sun::star::lang::EventObject& Source ) throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+// css::lang::XEventListener
+ virtual void SAL_CALL disposing( const css::lang::EventObject& Source ) throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
void dispose();
};
-sal_Int16 getControlTypeByObject(const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XServiceInfo>& _rxObject);
+sal_Int16 getControlTypeByObject(const css::uno::Reference< css::lang::XServiceInfo>& _rxObject);
// get the object type (OBJ_FM_...) from the services the object supports
-bool isRowSetAlive(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>& _rxRowSet);
- // checks if the ::com::sun::star::sdbcx::XColumnsSupplier provided by _rxRowSet supllies any columns
+bool isRowSetAlive(const css::uno::Reference< css::uno::XInterface>& _rxRowSet);
+ // checks if the css::sdbcx::XColumnsSupplier provided by _rxRowSet supllies any columns
-typedef ::std::set < ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >
- , ::comphelper::OInterfaceCompare< ::com::sun::star::uno::XInterface >
+typedef ::std::set < css::uno::Reference< css::uno::XInterface >
+ , ::comphelper::OInterfaceCompare< css::uno::XInterface >
> InterfaceBag;
#endif // INCLUDED_SVX_FMTOOLS_HXX
commit b839be53a78f64d4613765fd5f39f51fc7893423
Author: Thomas Arnhold <thomas at arnhold.org>
Date: Sun Aug 17 01:18:55 2014 +0200
warning C4800: 'int' : forcing value to bool 'true' or 'false'
Change-Id: I810e2b963f02c67d10765444cae2b5ec846af746